# BillingAccountCurrencyMigrationSpec

Controls how to migrate a customer from one billing account to another when changing currency. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**new_currency** | **str** | The currency in which this customer is charged. | 
**subscription_lifecycle** | [**BillingAccountMigrationSubscriptionLifecycle**](BillingAccountMigrationSubscriptionLifecycle.md) |  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


